_`oncilla.buildApi`
===================

.. automodule:: oncilla.buildApi

Module Attributes
-----------------

.. attribute:: oncilla.buildApi.LOGGER

.. attribute:: oncilla.buildApi.FILES_EXTENSION

.. attribute:: oncilla.buildApi.TOCTREE_TEMPLATE_BEGIN

.. attribute:: oncilla.buildApi.TOCTREE_TEMPLATE_END

.. attribute:: oncilla.buildApi.SANITIZER

Functions
---------

.. autofunction:: importSanitizer

.. autofunction:: buildApi

.. autofunction:: getCommandLineArguments

.. autofunction:: main

